pub struct TestInput {
pub file_path: String,
pub output_path: String,
pub new_fn_name: String,
pub start_idx: u32,
pub end_idx: u32,
}Expand description
A TestInput needs a Path to write to, as part of the testing process is writing the output to a file. This is not needed for the actual extraction
Fields
file_path: Stringoutput_path: Stringnew_fn_name: Stringstart_idx: u32end_idx: u32Trait Implementations
Sourceimpl From<&TestInput> for ExtractionInput
Because the TestInput contains an output path, it also needs to be converted
into an ExtractionInput for the actual extraction process
impl From<&TestInput> for ExtractionInput
Because the TestInput contains an output path, it also needs to be converted into an ExtractionInput for the actual extraction process
Sourcefn from(test_input: &TestInput) -> ExtractionInput
fn from(test_input: &TestInput) -> ExtractionInput
Converts to this type from the input type.