extract_method

Function extract_method 

pub fn extract_method(
    input: ExtractionInput,
) -> Result<(String, String), ExtractionError>
Function to extract the code segment based on cursor positions If successful, returns the String of the output code, followed by a String of the caller method