apply_extract_function

Function apply_extract_function 

pub fn apply_extract_function(
    assist: &Assist,
    input_path: &AbsPathBuf,
    vfs: &Vfs,
    callee_name: &str,
) -> Result<String, ExtractionError>
Applies the extract_function source change to the given code Returns the String of the output code Renames the function from fun_name to callee_name. Requires the output path to be an AbsPathBuf.