Module startup

Module startup 

This module is responsible for the startup information needed for the extractor to have context about the binary being analyzed. It build out a Workspace around std / core, and then we extend that workspace with our single file to allow for 90% of the features of Rust-Analyzer to work properly. Crucially this allows the extract method to get much better type information about the code being analyzed.

Modules

context
identify
types

Functions

single_file_std_context