pub fn parent_method(
source_file: &SourceFile,
range: (u32, u32),
) -> Result<String, ExtractionError>Expand description
Gets the caller method, based on the input code and the cursor positions
If successful, returns the String of the caller method
If unsuccessful, returns an ExtractionError