pub fn extract_method(input: ExtractionInput) -> Result<String, ExtractionError>Expand description
Function to extract the code segment based on cursor positions
If successful, returns the String of the output code
pub fn extract_method(input: ExtractionInput) -> Result<String, ExtractionError>Function to extract the code segment based on cursor positions
If successful, returns the String of the output code