pub fn extract_method(
input: ExtractionInput,
) -> Result<PathBuf, ExtractionError>Expand description
Function to extract the code segment based on cursor positions
If successful, returns the PathBuf to the output file
pub fn extract_method(
input: ExtractionInput,
) -> Result<PathBuf, ExtractionError>Function to extract the code segment based on cursor positions
If successful, returns the PathBuf to the output file